"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParsedPluginConfiguration = void 0;
const path_1 = require("path");
const schema_1 = require("./schema");
const defaults = {
    defaultSchemaName: "public",
};
class ParsedPluginConfiguration {
    constructor(project, logger) {
        this.project = project;
        this.logger = logger;
        this.defaultSchemaName = defaults.defaultSchemaName;
    }
    update(config) {
        this.logger.log("new config: " + JSON.stringify(config));
        this.schema = undefined;
        if (config.schemaFile) {
            const fullPath = path_1.resolve(this.project.getCurrentDirectory(), config.schemaFile);
            this.logger.log(`reading schema file from: ${fullPath}`);
            const content = this.project.readFile(fullPath);
            if (content) {
                try {
                    this.schema = schema_1.parseSchema(content);
                }
                catch (e) {
                    this.logger.log(`error parsing schema file: ${e.message}`);
                }
            }
        }
        this.defaultSchemaName =
            config.defaultSchemaName || defaults.defaultSchemaName;
    }
}
exports.ParsedPluginConfiguration = ParsedPluginConfiguration;
//# sourceMappingURL=configuration.js.map